pub struct MetadataMarker;Trait Implementations
Sourceimpl Clone for MetadataMarker
impl Clone for MetadataMarker
Sourcefn clone(&self) -> MetadataMarker
fn clone(&self) -> MetadataMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataMarker
impl Debug for MetadataMarker
Sourceimpl Hash for MetadataMarker
impl Hash for MetadataMarker
Sourceimpl Ord for MetadataMarker
impl Ord for MetadataMarker
Sourcefn cmp(&self, other: &MetadataMarker) -> Ordering
fn cmp(&self, other: &MetadataMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MetadataMarker
impl PartialEq for MetadataMarker
Sourceimpl PartialOrd for MetadataMarker
impl PartialOrd for MetadataMarker
Sourceimpl ProtocolMarker for MetadataMarker
impl ProtocolMarker for MetadataMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) Metadata"
const DEBUG_NAME: &'static str = "(anonymous) Metadata"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = MetadataProxy
type Proxy = MetadataProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = MetadataRequestStream
type RequestStream = MetadataRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = MetadataSynchronousProxy
type SynchronousProxy = MetadataSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for MetadataMarker
impl Eq for MetadataMarker
impl StructuralPartialEq for MetadataMarker