pub struct MetadataProxy { /* private fields */ }Implementations
Sourceimpl MetadataProxy
impl MetadataProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.driver.metadata/Metadata.
Sourcepub fn take_event_stream(&self) -> MetadataEventStream
pub fn take_event_stream(&self) -> MetadataEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_persisted_metadata(
&self,
) -> QueryResponseFut<MetadataGetPersistedMetadataResult, DefaultFuchsiaResourceDialect>
pub fn get_persisted_metadata( &self, ) -> QueryResponseFut<MetadataGetPersistedMetadataResult, DefaultFuchsiaResourceDialect>
Retrieve the persisted metadata provided by the server. Returns ZX_ERR_NOT_FOUND if the server does not have metadata to provide.