pub struct MetadataSynchronousProxy { /* private fields */ }Implementations
Sourceimpl MetadataSynchronousProxy
impl MetadataSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<MetadataEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<MetadataEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn get_persisted_metadata(
&self,
___deadline: MonotonicInstant,
) -> Result<MetadataGetPersistedMetadataResult, Error>
pub fn get_persisted_metadata( &self, ___deadline: MonotonicInstant, ) -> Result<MetadataGetPersistedMetadataResult, Error>
Retrieve the persisted metadata provided by the server. Returns ZX_ERR_NOT_FOUND if the server does not have metadata to provide.